@@ -11,12 +11,16 @@ Mandel - Async model layer for MongoDB objects using Mango
 
   package MyModel::Cat;
   use Mandel::Document;
-  field [qw( name type )];
+  use Types::Standard 'Str';
+  field name => ( isa => Str );
+  field 'type';
   belongs_to person => 'MyModel::Person';
 
   package MyModel::Person;
   use Mandel::Document;
-  field [qw( name age )];
+  use Types::Standard 'Int';
+  field [qw( name )];
+  field age => ( isa => Int );
   has_many cats => 'MyModel::Cat';
   has_one favorite_cat => 'MyModel::Cat';
 
@@ -89,7 +93,7 @@ use Mandel::Model;
 use Mango;
 use Carp 'confess';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 my $LOADER = Mojo::Loader->new;
 
